@@ -49,9 +49,10 @@ from airflow.exceptions import (
     DeserializingResultError,
 )
 from airflow.models.variable import Variable
+from airflow.providers.common.compat.sdk import context_merge
 from airflow.providers.standard.hooks.package_index import PackageIndexHook
 from airflow.providers.standard.utils.python_virtualenv import prepare_virtualenv, write_python_script
-from airflow.providers.standard.version_compat import AIRFLOW_V_3_0_PLUS, BaseOperator, context_merge
+from airflow.providers.standard.version_compat import AIRFLOW_V_3_0_PLUS, BaseOperator
 from airflow.utils import hashlib_wrapper
 from airflow.utils.file import get_unique_dag_module_name
 from airflow.utils.operator_helpers import KeywordParameters
@@ -72,14 +73,10 @@ if TYPE_CHECKING:
 
     from pendulum.datetime import DateTime
 
+    from airflow.providers.common.compat.sdk import Context
     from airflow.sdk.execution_time.callback_runner import ExecutionCallableRunner
     from airflow.sdk.execution_time.context import OutletEventAccessorsProtocol
 
-    try:
-        from airflow.sdk.definitions.context import Context
-    except ImportError:  # TODO: Remove once provider drops support for Airflow 2
-        from airflow.utils.context import Context
-
     _SerializerTypeDef = Literal["pickle", "cloudpickle", "dill"]
 
 
